@@ -74,8 +74,6 @@ References
 # Author:  Travis Oliphant 2000
 # Updated Sep. 2003 (fixed bugs --- tested to be accurate)
 
-from __future__ import division, print_function, absolute_import
-
 # SciPy imports.
 import numpy as np
 from numpy import (exp, inf, pi, sqrt, floor, sin, cos, around, int,
@@ -140,15 +138,13 @@ class orthopoly1d(np.poly1d):
         poly = np.poly1d(roots, r=True)
         np.poly1d.__init__(self, poly.coeffs * float(kn))
 
-        # TODO: In numpy 1.13, there is no need to use __dict__ to access attributes
-        self.__dict__['weights'] = np.array(list(zip(roots,
-                                                     weights, equiv_weights)))
-        self.__dict__['weight_func'] = wfunc
-        self.__dict__['limits'] = limits
-        self.__dict__['normcoef'] = mu
+        self.weights = np.array(list(zip(roots, weights, equiv_weights)))
+        self.weight_func = wfunc
+        self.limits = limits
+        self.normcoef = mu
 
         # Note: eval_func will be discarded on arithmetic
-        self.__dict__['_eval_func'] = eval_func
+        self._eval_func = eval_func
 
     def __call__(self, v):
         if self._eval_func and not isinstance(v, np.poly1d):
@@ -159,18 +155,12 @@ class orthopoly1d(np.poly1d):
     def _scale(self, p):
         if p == 1.0:
             return
-        try:
-            self._coeffs
-        except AttributeError:
-            self.__dict__['coeffs'] *= p
-        else:
-            # the coeffs attr is be made private in future versions of numpy
-            self._coeffs *= p
+        self._coeffs *= p
 
         evf = self._eval_func
         if evf:
-            self.__dict__['_eval_func'] = lambda x: evf(x) * p
-        self.__dict__['normcoef'] *= p
+            self._eval_func = lambda x: evf(x) * p
+        self.normcoef *= p
 
 
 def _gen_roots_and_weights(n, mu0, an_func, bn_func, f, df, symmetrize, mu):
@@ -222,7 +212,7 @@ def roots_jacobi(n, alpha, beta, mu=False):
     r"""Gauss-Jacobi quadrature.
 
     Compute the sample points and weights for Gauss-Jacobi
-    quadrature. The sample points are the roots of the n-th degree
+    quadrature. The sample points are the roots of the nth degree
     Jacobi polynomial, :math:`P^{\alpha, \beta}_n(x)`. These sample
     points and weights correctly integrate polynomials of degree
     :math:`2n - 1` or less over the interval :math:`[-1, 1]` with
@@ -352,7 +342,7 @@ def roots_sh_jacobi(n, p1, q1, mu=False):
     """Gauss-Jacobi (shifted) quadrature.
 
     Compute the sample points and weights for Gauss-Jacobi (shifted)
-    quadrature. The sample points are the roots of the n-th degree
+    quadrature. The sample points are the roots of the nth degree
     shifted Jacobi polynomial, :math:`G^{p,q}_n(x)`. These sample
     points and weights correctly integrate polynomials of degree
     :math:`2n - 1` or less over the interval :math:`[0, 1]` with
@@ -450,7 +440,7 @@ def sh_jacobi(n, p, q, monic=False):
     x, w, mu0 = roots_sh_jacobi(n1, p, q, mu=True)
     hn = _gam(n + 1) * _gam(n + q) * _gam(n + p) * _gam(n + p - q + 1)
     hn /= (2 * n + p) * (_gam(2 * n + p)**2)
-    # kn = 1.0 in standard form so monic is redundant.  Kept for compatibility.
+    # kn = 1.0 in standard form so monic is redundant. Kept for compatibility.
     kn = 1.0
     pp = orthopoly1d(x, w, hn, kn, wfunc=wfunc, limits=(0, 1), monic=monic,
                      eval_func=lambda x: eval_sh_jacobi(n, p, q, x))
@@ -463,7 +453,7 @@ def roots_genlaguerre(n, alpha, mu=False):
     r"""Gauss-generalized Laguerre quadrature.
 
     Compute the sample points and weights for Gauss-generalized
-    Laguerre quadrature. The sample points are the roots of the n-th
+    Laguerre quadrature. The sample points are the roots of the nth
     degree generalized Laguerre polynomial, :math:`L^{\alpha}_n(x)`.
     These sample points and weights correctly integrate polynomials of
     degree :math:`2n - 1` or less over the interval :math:`[0,
@@ -592,7 +582,7 @@ def roots_laguerre(n, mu=False):
     r"""Gauss-Laguerre quadrature.
 
     Compute the sample points and weights for Gauss-Laguerre
-    quadrature. The sample points are the roots of the n-th degree
+    quadrature. The sample points are the roots of the nth degree
     Laguerre polynomial, :math:`L_n(x)`. These sample points and
     weights correctly integrate polynomials of degree :math:`2n - 1`
     or less over the interval :math:`[0, \infty]` with weight function
@@ -679,10 +669,10 @@ def laguerre(n, monic=False):
 
 
 def roots_hermite(n, mu=False):
-    r"""Gauss-Hermite (physicst's) quadrature.
+    r"""Gauss-Hermite (physicist's) quadrature.
 
     Compute the sample points and weights for Gauss-Hermite
-    quadrature. The sample points are the roots of the n-th degree
+    quadrature. The sample points are the roots of the nth degree
     Hermite polynomial, :math:`H_n(x)`. These sample points and
     weights correctly integrate polynomials of degree :math:`2n - 1`
     or less over the interval :math:`[-\infty, \infty]` with weight
@@ -834,7 +824,7 @@ def _initial_nodes_a(n, k):
 def _initial_nodes_b(n, k):
     r"""Gatteschi initial guesses
 
-    Computes an initial approximation to the square of the `k`-th
+    Computes an initial approximation to the square of the kth
     (positive) root :math:`x_k` of the Hermite polynomial :math:`H_n`
     of order :math:`n`. The formula is the one from lemma 3.2 in the
     original paper. The guesses are accurate in the region just
@@ -1068,11 +1058,11 @@ def _newton(n, x_initial, maxit=5):
 
 
 def _roots_hermite_asy(n):
-    r"""Gauss-Hermite (physicst's) quadrature for large n.
+    r"""Gauss-Hermite (physicist's) quadrature for large n.
 
     Computes the sample points and weights for Gauss-Hermite quadrature.
-    The sample points are the roots of the n-th degree Hermite polynomial,
-    :math:`H_n(x)`.  These sample points and weights correctly integrate
+    The sample points are the roots of the nth degree Hermite polynomial,
+    :math:`H_n(x)`. These sample points and weights correctly integrate
     polynomials of degree :math:`2n - 1` or less over the interval
     :math:`[-\infty, \infty]` with weight function :math:`f(x) = e^{-x^2}`.
 
@@ -1178,7 +1168,7 @@ def roots_hermitenorm(n, mu=False):
     r"""Gauss-Hermite (statistician's) quadrature.
 
     Compute the sample points and weights for Gauss-Hermite
-    quadrature. The sample points are the roots of the n-th degree
+    quadrature. The sample points are the roots of the nth degree
     Hermite polynomial, :math:`He_n(x)`. These sample points and
     weights correctly integrate polynomials of degree :math:`2n - 1`
     or less over the interval :math:`[-\infty, \infty]` with weight
@@ -1305,7 +1295,7 @@ def roots_gegenbauer(n, alpha, mu=False):
     r"""Gauss-Gegenbauer quadrature.
 
     Compute the sample points and weights for Gauss-Gegenbauer
-    quadrature. The sample points are the roots of the n-th degree
+    quadrature. The sample points are the roots of the nth degree
     Gegenbauer polynomial, :math:`C^{\alpha}_n(x)`. These sample
     points and weights correctly integrate polynomials of degree
     :math:`2n - 1` or less over the interval :math:`[-1, 1]` with
@@ -1416,8 +1406,8 @@ def roots_chebyt(n, mu=False):
     r"""Gauss-Chebyshev (first kind) quadrature.
 
     Computes the sample points and weights for Gauss-Chebyshev
-    quadrature. The sample points are the roots of the n-th degree
-    Chebyshev polynomial of the first kind, :math:`T_n(x)`.  These
+    quadrature. The sample points are the roots of the nth degree
+    Chebyshev polynomial of the first kind, :math:`T_n(x)`. These
     sample points and weights correctly integrate polynomials of
     degree :math:`2n - 1` or less over the interval :math:`[-1, 1]`
     with weight function :math:`w(x) = 1/\sqrt{1 - x^2}`. See 22.2.4
@@ -1519,7 +1509,7 @@ def roots_chebyu(n, mu=False):
     r"""Gauss-Chebyshev (second kind) quadrature.
 
     Computes the sample points and weights for Gauss-Chebyshev
-    quadrature. The sample points are the roots of the n-th degree
+    quadrature. The sample points are the roots of the nth degree
     Chebyshev polynomial of the second kind, :math:`U_n(x)`. These
     sample points and weights correctly integrate polynomials of
     degree :math:`2n - 1` or less over the interval :math:`[-1, 1]`
@@ -1614,7 +1604,7 @@ def roots_chebyc(n, mu=False):
     r"""Gauss-Chebyshev (first kind) quadrature.
 
     Compute the sample points and weights for Gauss-Chebyshev
-    quadrature. The sample points are the roots of the n-th degree
+    quadrature. The sample points are the roots of the nth degree
     Chebyshev polynomial of the first kind, :math:`C_n(x)`. These
     sample points and weights correctly integrate polynomials of
     degree :math:`2n - 1` or less over the interval :math:`[-2, 2]`
@@ -1720,7 +1710,7 @@ def roots_chebys(n, mu=False):
     r"""Gauss-Chebyshev (second kind) quadrature.
 
     Compute the sample points and weights for Gauss-Chebyshev
-    quadrature. The sample points are the roots of the n-th degree
+    quadrature. The sample points are the roots of the nth degree
     Chebyshev polynomial of the second kind, :math:`S_n(x)`. These
     sample points and weights correctly integrate polynomials of
     degree :math:`2n - 1` or less over the interval :math:`[-2, 2]`
@@ -1827,7 +1817,7 @@ def roots_sh_chebyt(n, mu=False):
     r"""Gauss-Chebyshev (first kind, shifted) quadrature.
 
     Compute the sample points and weights for Gauss-Chebyshev
-    quadrature. The sample points are the roots of the n-th degree
+    quadrature. The sample points are the roots of the nth degree
     shifted Chebyshev polynomial of the first kind, :math:`T_n(x)`.
     These sample points and weights correctly integrate polynomials of
     degree :math:`2n - 1` or less over the interval :math:`[0, 1]`
@@ -1907,7 +1897,7 @@ def roots_sh_chebyu(n, mu=False):
     r"""Gauss-Chebyshev (second kind, shifted) quadrature.
 
     Computes the sample points and weights for Gauss-Chebyshev
-    quadrature. The sample points are the roots of the n-th degree
+    quadrature. The sample points are the roots of the nth degree
     shifted Chebyshev polynomial of the second kind, :math:`U_n(x)`.
     These sample points and weights correctly integrate polynomials of
     degree :math:`2n - 1` or less over the interval :math:`[0, 1]`
@@ -1991,7 +1981,7 @@ def roots_legendre(n, mu=False):
     r"""Gauss-Legendre quadrature.
 
     Compute the sample points and weights for Gauss-Legendre
-    quadrature. The sample points are the roots of the n-th degree
+    quadrature. The sample points are the roots of the nth degree
     Legendre polynomial :math:`P_n(x)`. These sample points and
     weights correctly integrate polynomials of degree :math:`2n - 1`
     or less over the interval :math:`[-1, 1]` with weight function
@@ -2100,7 +2090,7 @@ def roots_sh_legendre(n, mu=False):
     r"""Gauss-Legendre (shifted) quadrature.
 
     Compute the sample points and weights for Gauss-Legendre
-    quadrature. The sample points are the roots of the n-th degree
+    quadrature. The sample points are the roots of the nth degree
     shifted Legendre polynomial :math:`P^*_n(x)`. These sample points
     and weights correctly integrate polynomials of degree :math:`2n -
     1` or less over the interval :math:`[0, 1]` with weight function
@@ -2190,6 +2180,9 @@ def sh_legendre(n, monic=False):
 # module directly. (They shouldn't be; it's not in the public API).
 poch = cephes.poch
 
+# eval_chebyu, eval_sh_chebyt and eval_sh_chebyu: These functions are not
+# used in orthogonal.py, they are not in _rootfuns_map, but their names
+# do appear in _evalfuns, so they must be kept.
 from ._ufuncs import (binom, eval_jacobi, eval_sh_jacobi, eval_gegenbauer,
                       eval_chebyt, eval_chebyu, eval_chebys, eval_chebyc,
                       eval_sh_chebyt, eval_sh_chebyu, eval_legendre,
